<TS version="2.1" language="kn">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">ವಿಳಾಸ ಅಥವಾ ಲೇಬಲ್ ಅನ್ನು ಪರಿಷ್ಕರಿಸಲು ಬಲ ಕ್ಲಿಕ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">ಹೊಸ ವಿಳಾಸವನ್ನು ಸೃಷ್ಟಿ ಮಾಡಿ</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;ಹೊಸ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;ನಕಲು</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">ಮುಚ್ಚು</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">ಪಟ್ಟಿಯಿಂದ ಈಗ ಆಯ್ಕೆಯಾಗಿರುವ ವಿಳಾಸವನ್ನು ಅಳಿಸಿಕೊಳ್ಳಿ.</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">ಹುಡುಕಲು ವಿಳಾಸ ಅಥವಾ ಲೇಬಲ್ ನಮೂದಿಸಿ.</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">ಪ್ರಸ್ತುತ ಟ್ಯಾಬ್‌ನಲ್ಲಿರುವ ಡೇಟಾವನ್ನು ಫೈಲ್‌ಗೆ ರಫ್ತು ಮಾಡಿ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ರಫ್ತು ಮಾಡಿ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;ಅಳಿಸಿ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">ನಾಣ್ಯಗಳನ್ನು ಕಳುಹಿಸಲು ವಿಳಾಸವನ್ನು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ನಾಣ್ಯಗಳನ್ನು ಸ್ವೀಕರಿಸಲು ವಿಳಾಸವನ್ನು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;ಕೆಳಗೆ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">ಕಾಣಿಕೆಗಳು ಕಳುಹಿಸಲು ನೀವು ಬಳಸಬಹುದಿರುವ ಬಿಟ್‌ಕಾಯಿನ್ ವಿಳಾಸಗಳು ಇವು. ನಾಣ್ಯದ ಹಣವನ್ನು ಕಳುಹಿಸುವ ಮುಂದೆ ಹಣದ ಮೊತ್ತವನ್ನು ಮತ್ತು ಪ್ರಾಪ್ತಿ ವಿಳಾಸವನ್ನು ಯಾವಾಗಲೂ ಪರಿಶೀಲಿಸಿ.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">ನೀವು ಪಡೆಯಲು ಬಯಸುವ ಪಾವತಿಗಳನ್ನು ಸೇರಿಸಲು ನಿಮ್ಮ ಬಿಟ್‌ಕಾಯಿನ್ ವಿಳಾಸಗಳು ಇವು. ಹೊಸ ವಿಳಾಸಗಳನ್ನು ರಚಿಸಲು ಪಡೆಯುವ ಉಪಕರಣವಾಗಿ 'ಪಡೆಯುವ' ಟ್ಯಾಬ್ ನಲ್ಲಿರುವ 'ಹೊಸ ಪಾವತಿಯನ್ನು ರಚಿಸಿ' ಬಟನ್ ಅನ್ನು ಬಳಸಿ. ಸಹಿ ಮಾಡುವುದು ಕೇವಲ 'ಲೆಗೆಸಿ' ವಿಳಾಸಗಳ ವರ್ಗಕ್ಕೆ ಸೇರಿದ ವಿಳಾಸಗಳೊಂದಿಗೆ ಮಾತ್ರ ಸಾಧ್ಯ.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;ವಿಳಾಸವನ್ನು ನಕಲಿಸಿ</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">ನಕಲು&amp;ಲೇಬಲ್</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;ಸಂಪಾದಿಸು</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">ರಫ್ತು ವಿಳಾಸ ಪಟ್ಟಿ</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">ಅಲ್ಪವಿರಾಮದಿಂದ ಬೇರ್ಪಡಿಸಿದ ಫೈಲ್</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">ವಿಳಾಸ ಪಟ್ಟಿಯನ್ನು %1 ಗೆ ಉಳಿಸಲು ಪ್ರಯತ್ನಿಸುವಾಗ ದೋಷ ಕಂಡುಬಂದಿದೆ. ದಯವಿಟ್ಟು ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">ವಿಳಾಸಗಳನ್ನು ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">ವಿಳಾಸಗಳನ್ನು ಸ್ವೀಕರಿಸಲಾಗುತ್ತಿದೆ - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">ರಫ್ತು ವಿಫಲವಾಗಿದೆ</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">ಲೇಬಲ್</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ವಿಳಾಸ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ಲೇಬಲ್ ಇಲ್ಲ)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">ಪಾಸ್‌ಫ್ರೇಸ್ ಸಂವಾದ</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">ಪಾಸ್‌ಫ್ರೇಸ್ ನಮೂದಿಸಿ</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">ಹೊಸ ಪಾಸ್‌ಫ್ರೇಸ್</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">ಹೊಸ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ಪುನರಾವರ್ತಿಸಿ</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">ಪಾಸ್‌ಫ್ರೇಸ್ ತೋರಿಸಿ</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಟ್ (ಗೂಢಲಿಪೀಕರಣ) ಮಾಡಿ</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">ಈ ಕ್ರಿಯೆಗೆ ನಿಮ್ಮ ವಾಲೆಟ್ ಲಾಕ್ ಮುಕ್ತಗೊಳಿಸಲು ನಿಮ್ಮ ವಾಲೆಟ್ ಪಾಸ್‌ಫ್ರೇಸ್ ಅಗತ್ಯವಿದೆ.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಅನ್ನು ಅನ್ಲಾಕ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">ಪಾಸ್‌ಫ್ರೇಸ್ ಬದಲಾಯಿಸಿ</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಶನ್(ಗೂಢಲಿಪೀಕರಣ) ಅನ್ನು ದೃಢೀಕರಿಸಿ</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">ನೀವು ನಿಮ್ಮ ವ್ಯಾಲೆಟ್ ಅನ್ನು ಎನ್‌ಕ್ರಿಪ್ಟ್ ಮಾಡಿದರೆ ಮತ್ತು ನಿಮ್ಮ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ಕಳೆದುಕೊಂಡರೆ&lt;b&gt;, ನಿಮ್ಮ ಎಲ್ಲಾ &lt;/b&gt;ಬಿಟ್‌ಕಾಯಿನ್‌ಗಳನ್ನು ನೀವು ಕಳೆದುಕೊಳ್ಳುತ್ತೀರಿ 
 !</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">ನಿಮ್ಮ ವ್ಯಾಲೆಟ್ ಅನ್ನು ಎನ್‌ಕ್ರಿಪ್ಟ್ ಮಾಡಲು ನೀವು ಖಚಿತವಾಗಿ ಬಯಸುವಿರಾ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಟ್ ಮಾಡಲಾಗಿದೆ</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">ವ್ಯಾಲೆಟ್‌ಗಾಗಿ ಹೊಸ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ನಮೂದಿಸಿ.&lt;br/&gt;ದಯವಿಟ್ಟು &lt;b&gt;ಹತ್ತು ಅಥವಾ ಹೆಚ್ಚಿನ ಯಾದೃಚ್ಛಿಕ ಅಕ್ಷರಗಳ&lt;/b&gt; ಪಾಸ್‌ಫ್ರೇಸ್ ಅಥವಾ &lt;b&gt;ಎಂಟು ಅಥವಾ ಹೆಚ್ಚಿನ ಪದಗಳನ್ನು ಬಳಸಿ&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">ವಾಲೆಟ್‌ಗಾಗಿ ಹಳೆಯ ಪಾಸ್‌ಫ್ರೇಸ್ ಮತ್ತು ಹೊಸ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ನಮೂದಿಸಿ.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">ನಿಮ್ಮ ವಾಲೆಟ್ ಎನ್ಕ್ರಿಪ್ಟ್ ಮಾಡುವುದರಿಂದ ನಿಮ್ಮ ಕಂಪ್ಯೂಟರ್ ಸೋಕಿದ ಮಲ್ವೇರ್ ನೋಂದಣಿಗೆ ಬಲಗೊಳಿಸುವ ಕಾದಂಬರಿಗೆ ನಿಮ್ಮ ಬಿಟ್‌ಕಾಯಿನ್ ಪೂರ್ತಿಯಾಗಿ ಸುರಕ್ಷಿತವಾಗುವುದಿಲ್ಲವೆಂದು ನೆನಪಿಡಿ.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಅನ್ನು ಎನ್‌ಕ್ರಿಪ್ಟ್ ಮಾಡಬೇಕು</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">ನಿಮ್ಮ ವ್ಯಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಟ್ ಆಗಲಿದೆ.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">ನಿಮ್ಮ ವ್ಯಾಲೆಟ್ ಅನ್ನು ಈಗ ಎನ್‌ಕ್ರಿಪ್ಟ್ ಮಾಡಲಾಗಿದೆ.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">ಪ್ರಮುಖ: ನೀವು ಹಿಂದಿನದನ್ನು ತಯಾರಿಸಿದ ವಾಲೆಟ್ ಫೈಲ್‌ನ ಯಾವುದೇ ಹಿಂದಿನ ಬ್ಯಾಕಪ್‌ಗಳನ್ನು ಹೊಂದಿದ್ದರೆ ಅವುಗಳನ್ನು ಹೊಸದಾಗಿ ತಯಾರಿಸಲಿಕ್ಕೆ ಬದಲಾಯಿಸಬೇಕು. ಭದ್ರತೆ ಕಾರಣಕ್ಕಾಗಿ, ಅನ್ನುವಂತಹ ವಾಲೆಟ್ ಫೈಲ್‌ನ ಹಿಂದಿನ ಬ್ಯಾಕಪ್‌ಗಳು ಹೊಸದಾದ ಎನ್ಕ್ರಿಪ್ಟ್ ವಾಲೆಟ್ ಬಳಸುವಂತೆ ಆಗ ಹೇಗೆ ಪಾರುಮಾಡಲು ಅಸಮರ್ಥವಾಗುತ್ತವೆ.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಶನ್ ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಎನ್ಕ್ರಿಪ್ಷನ್ ಒಳಗಿನ ತಪಾಸಣಾ ದೋಷಕ್ಕೆ ಕಾರಣವಾಗಿ ವಾಲೆಟ್ ಎನ್ಕ್ರಿಪ್ಟ್ ಆಗಲಿಲ್ಲ.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">ಒದಗಿಸಿದ ಪಾಸ್‌ಫ್ರೇಸ್‌ಗಳು ಹೊಂದಿಕೆಯಾಗುವುದಿಲ್ಲ.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಅನ್‌ಲಾಕ್ ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">ವ್ಯಾಲೆಟ್ ಡೀಕ್ರಿಪ್ಶನ್‌ಗಾಗಿ ನಮೂದಿಸಿದ ಪಾಸ್‌ಫ್ರೇಸ್ ತಪ್ಪಾಗಿದೆ.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">ವ್ಯಾಲೆಟ್ ಡೀಕ್ರಿಪ್ಶನ್‌ಗಾಗಿ ನಮೂದಿಸಿದ ಪಾಸ್‌ಫ್ರೇಸ್ ತಪ್ಪಾಗಿದೆ. ಇದು ಶೂನ್ಯ ಅಕ್ಷರವನ್ನು ಹೊಂದಿರುತ್ತದೆ (ಅಂದರೆ - ಶೂನ್ಯ ಬೈಟ್). ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು 25.0 ಕ್ಕಿಂತ ಮೊದಲು ಈ ಸಾಫ್ಟ್‌ವೇರ್‌ನ ಆವೃತ್ತಿಯೊಂದಿಗೆ ಹೊಂದಿಸಿದ್ದರೆ, ದಯವಿಟ್ಟು ಮೊದಲ ಶೂನ್ಯ ಅಕ್ಷರದವರೆಗಿನ - ಆದರೆ ಒಳಗೊಂಡಿಲ್ಲದವರೆಗಿನ ಅಕ್ಷರಗಳೊಂದಿಗೆ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ. ಇದು ಯಶಸ್ವಿಯಾದರೆ, ಭವಿಷ್ಯದಲ್ಲಿ ಈ ಸಮಸ್ಯೆಯನ್ನು ತಪ್ಪಿಸಲು ದಯವಿಟ್ಟು ಹೊಸ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ಹೊಂದಿಸಿ.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ಯಶಸ್ವಿಯಾಗಿ ಬದಲಾಯಿಸಲಾಗಿದೆ.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">ಪಾಸ್‌ಫ್ರೇಸ್ ಬದಲಾವಣೆ ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">ವ್ಯಾಲೆಟ್ ಡೀಕ್ರಿಪ್ಶನ್‌ಗಾಗಿ ನಮೂದಿಸಿದ ಹಳೆಯ ಪಾಸ್‌ಫ್ರೇಸ್ ತಪ್ಪಾಗಿದೆ. ಇದು ಶೂನ್ಯ ಅಕ್ಷರವನ್ನು ಹೊಂದಿರುತ್ತದೆ (ಅಂದರೆ - ಶೂನ್ಯ ಬೈಟ್). ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು 25.0 ಕ್ಕಿಂತ ಮೊದಲು ಈ ಸಾಫ್ಟ್‌ವೇರ್‌ನ ಆವೃತ್ತಿಯೊಂದಿಗೆ ಹೊಂದಿಸಿದ್ದರೆ, ದಯವಿಟ್ಟು ಮೊದಲ ಶೂನ್ಯ ಅಕ್ಷರದವರೆಗಿನ - ಆದರೆ ಒಳಗೊಂಡಿಲ್ಲದವರೆಗಿನ ಅಕ್ಷರಗಳೊಂದಿಗೆ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">ಎಚ್ಚರಿಕೆ: ಕ್ಯಾಪ್ಸ್ ಲಾಕ್ ಕೀ ಆನ್ ಆಗಿದೆ!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">ಐಪಿ/ನೆಟ್‌ಮಾಸ್ಕ್</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">ತನಕ ನಿಷೇಧಿಸಲಾಗಿದೆ</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">ಸೆಟ್ಟಿಂಗ್ಸ್ ಫೈಲ್ %1 ದೋಷಪೂರಿತ ಅಥವಾ ಅಮಾನ್ಯವಾಗಿರಬಹುದು.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">ಓಡಿಹೋದ ವಿನಾಯಿತಿ</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">ಮಾರಣಾಂತಿಕ ದೋಷ ಸಂಭವಿಸಿದೆ. %1 ಇನ್ನು ಮುಂದೆ ಸುರಕ್ಷಿತವಾಗಿ ಮುಂದುವರಿಯಲು ಸಾಧ್ಯವಿಲ್ಲ ಮತ್ತು ನಿರ್ಗಮಿಸುತ್ತದೆ.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">ಆಂತರಿಕ ದೋಷ</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">ಆಂತರಿಕ ದೋಷ ಸಂಭವಿಸಿದೆ. %1 ಸುರಕ್ಷಿತವಾಗಿ ಮುಂದುವರಿಯಲು ಪ್ರಯತ್ನಿಸುತ್ತದೆ. ಇದು ಅನಿರೀಕ್ಷಿತ ದೋಷವಾಗಿದ್ದು ಇದನ್ನು ಕೆಳಗೆ ವಿವರಿಸಿದಂತೆ ವರದಿ ಮಾಡಬಹುದು.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">ನೀವು ಸೆಟ್ಟಿಂಗ್‌ಗಳನ್ನು ಡೀಫಾಲ್ಟ್ ಮೌಲ್ಯಗಳಿಗೆ ಮರುಹೊಂದಿಸಲು ಬಯಸುವಿರಾ ಅಥವಾ ಬದಲಾವಣೆಗಳನ್ನು ಮಾಡದೆಯೇ ಸ್ಥಗಿತಗೊಳಿಸಲು ಬಯಸುವಿರಾ?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">ಮಾರಣಾಂತಿಕ ದೋಷ ಸಂಭವಿಸಿದೆ. ಸೆಟ್ಟಿಂಗ್‌ಗಳ ಫೈಲ್ ಬರೆಯಬಹುದೇ ಎಂದು ಪರಿಶೀಲಿಸಿ ಅಥವಾ -ನೋ ಸೆಟ್ಟಿಂಗ್‌ಗಳೊಂದಿಗೆ ಚಲಾಯಿಸಲು ಪ್ರಯತ್ನಿಸಿ.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">ದೋಷ: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 ಇನ್ನೂ ಸುರಕ್ಷಿತವಾಗಿ ನಿರ್ಗಮಿಸಿಲ್ಲ...</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;ಅವಲೋಕನ</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">ವಾಲೆಟ್ನ ಸಾಮಾನ್ಯ ಅವಲೋಕನವನ್ನು ತೋರಿಸಿ</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;ವ್ಯವಹಾರಗಳು</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">ವಹಿವಾಟಿನ ಇತಿಹಾಸವನ್ನು ಬ್ರೌಸ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;ನಿರ್ಗಮಿಸಿ</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">ಅಪ್ಲಿಕೇಶನ್ ತ್ಯಜಿಸಿ</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;ಸುಮಾರು %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">%1 ರ ಬಗ್ಗೆ ಮಾಹಿತಿಯನ್ನು ತೋರಿಸಿ</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished"> ಕುರಿತು &amp; ಕ್ಯೂಟಿ</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished"> ಕ್ಯೂಟಿ ಕುರಿತು ಮಾಹಿತಿಯನ್ನು ತೋರಿಸಿ</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">%1 ಗಾಗಿ ಸಂರಚನಾ ಆಯ್ಕೆಗಳನ್ನು ಮಾರ್ಪಡಿಸಿ</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">ಹೊಸ ವಾಲೆಟ್ (ವಿಳಾಸ) ರಚಿಸಿ</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;ಕಡಿಮೆಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">ವಾಲೆಟ್ (ವಿಳಾಸ):</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">ನೆಟ್‌ವರ್ಕ್ ಚಟುವಟಿಕೆಯನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">ಪ್ರಾಕ್ಸಿಯನ್ನು &lt;b&gt; ಸಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">ಬಿಟ್‌ಕಾಯಿನ್ ವಿಳಾಸಕ್ಕೆ ನಾಣ್ಯಗಳನ್ನು ಕಳುಹಿಸಿ</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">ಬೇರೊಂದು ಸ್ಥಳಕ್ಕೆ ವಾಲೆಟ್ ಬ್ಯಾಕಪ್  ಮಾಡಿ</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">ವ್ಯಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಶನ್‌ಗಾಗಿ ಬಳಸುವ ಪಾಸ್‌ಫ್ರೇಸ್ ಅನ್ನು ಬದಲಾಯಿಸಿ</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;ಕಳುಹಿಸು</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;ಸ್ವೀಕರಿಸಿ</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;ಆಯ್ಕೆಗಳು...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಎನ್‌ಕ್ರಿಪ್ಟ್ (ಗೂಢಲಿಪೀಕರಣ) ಮಾಡಿ</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">ನಿಮ್ಮ ವ್ಯಾಲೆಟ್‌ಗೆ ಸೇರಿದ ಖಾಸಗಿ ಕೀಗಳನ್ನು ಎನ್‌ಕ್ರಿಪ್ಟ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;ಬ್ಯಾಕಪ್ ವಾಲೆಟ್...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;ಪಾಸ್‌ಫ್ರೇಸ್ ಬದಲಾಯಿಸಿ...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">ಸಹಿ &amp;ಸಂದೇಶ...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">ನೀವು ಅವುಗಳನ್ನು ಹೊಂದಿದ್ದೀರಿ ಎಂದು ಸಾಬೀತುಪಡಿಸಲು ನಿಮ್ಮ ಬಿಟ್‌ಕಾಯಿನ್ ವಿಳಾಸಗಳೊಂದಿಗೆ ಸಂದೇಶಗಳಿಗೆ ಸಹಿ ಮಾಡಿ</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;ಸಂದೇಶವನ್ನು ಪರಿಶೀಲಿಸಿ...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">ನಿರ್ದಿಷ್ಟಪಡಿಸಿದ ಬಿಟ್‌ಕಾಯಿನ್ ವಿಳಾಸಗಳೊಂದಿಗೆ ಸಹಿ ಮಾಡಿರುವುದನ್ನು ಖಚಿತಪಡಿಸಿಕೊಳ್ಳಲು ಸಂದೇಶಗಳನ್ನು ಪರಿಶೀಲಿಸಿ</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;ಫೈಲ್‌ನಿಂದ PSBT ಅನ್ನು ಲೋಡ್ ಮಾಡಿ...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">ತೆರೆಯಿರಿ &amp; URI...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">ವಾಲೆಟ್ ಅನ್ನು ಮುಚ್ಚಿ...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">ವಾಲೆಟ್ ರಚಿಸಿ...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">ಎಲ್ಲಾ ವ್ಯಾಲೆಟ್‌ಗಳನ್ನು ಮುಚ್ಚಿ...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;ಫೈಲ್</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;ಸೆಟ್ಟಿಂಗ್‌ಗಳು</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;ಸಹಾಯ</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">ಟ್ಯಾಬ್‌ಗಳ ಟೂಲ್‌ಬಾರ್</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">ಶೀರ್ಷಿಕೆಗಳನ್ನು ಸಿಂಕ್ ಮಾಡಲಾಗುತ್ತಿದೆ (%1%)...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">ನೆಟ್‌ವರ್ಕ್‌ನೊಂದಿಗೆ ಸಿಂಕ್ರೊನೈಸ್ ಮಾಡಲಾಗುತ್ತಿದೆ...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">ಡಿಸ್ಕ್‌ನಲ್ಲಿ ಬ್ಲಾಕ್‌ಗಳನ್ನು ಸೂಚಿಕೆ ಮಾಡಲಾಗುತ್ತಿದೆ...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">ಡಿಸ್ಕ್‌ನಲ್ಲಿ ಬ್ಲಾಕ್‌ಗಳನ್ನು ಪ್ರಕ್ರಿಯೆಗೊಳಿಸಲಾಗುತ್ತಿದೆ...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">ಗೆಳೆಯರೊಂದಿಗೆ ಸಂಪರ್ಕಿಸಲಾಗುತ್ತಿದೆ...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">ಪಾವತಿಗಳನ್ನು ವಿನಂತಿಸಿ (QR ಕೋಡ್‌ಗಳು ಮತ್ತು ಬಿಟ್‌ಕಾಯಿನ್‌ಗಳನ್ನು ಉತ್ಪಾದಿಸುತ್ತದೆ: URI ಗಳು)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">ಬಳಸಿದ ಕಳುಹಿಸುವ ವಿಳಾಸಗಳು ಮತ್ತು ಲೇಬಲ್‌ಗಳ ಪಟ್ಟಿಯನ್ನು ತೋರಿಸಿ</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">ದೋಷ: %1</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ಲೇಬಲ್ ಇಲ್ಲ)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB of space available</numerusform>
            <numerusform>%n GB of space available</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">ವಿಳಾಸ</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">ವಾಲೆಟ್ (ವಿಳಾಸ):</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">ಲೇಬಲ್</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ಲೇಬಲ್ ಇಲ್ಲ)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ಲೇಬಲ್ ಇಲ್ಲ)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">ಲೇಬಲ್</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ಲೇಬಲ್ ಇಲ್ಲ)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">ಅಲ್ಪವಿರಾಮದಿಂದ ಬೇರ್ಪಡಿಸಿದ ಫೈಲ್</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">ಲೇಬಲ್</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ವಿಳಾಸ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">ರಫ್ತು ವಿಫಲವಾಗಿದೆ</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">ಹೊಸ ವಾಲೆಟ್ (ವಿಳಾಸ) ರಚಿಸಿ</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ರಫ್ತು ಮಾಡಿ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">ಪ್ರಸ್ತುತ ಟ್ಯಾಬ್‌ನಲ್ಲಿರುವ ಡೇಟಾವನ್ನು ಫೈಲ್‌ಗೆ ರಫ್ತು ಮಾಡಿ</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>The block database contains a block which appears to be from the future. This may be due to your computer's date and time being set incorrectly. Only rebuild the block database if you are sure that your computer's date and time are correct</source>
        <translation type="unfinished">ಬ್ಲಾಕ್ ಡೇಟಾಬೇಸ್ ಭವಿಷ್ಯದಿಂದ ಬಂದಿರುವ ಬ್ಲಾಕ್ ಹೊಂದಿದೆ ಎಂದು ತೋರುತ್ತದೆ. ಇದು ನಿಮ್ಮ ಕಂಪ್ಯೂಟರ್ನ ದಿನಾಂಕ ಮತ್ತು ಸಮಯವು ತಪ್ಪಾಗಿರಬಹುದು. ನಿಮ್ಮ ಕಂಪ್ಯೂಟರ್ನ ದಿನಾಂಕ ಮತ್ತು ಸಮಯ ಸರಿಯಾಗಿದ್ದರೆ, ಬ್ಲಾಕ್ ಡೇಟಾಬೇಸ್ ಮಾತ್ರವೇ ಪುನಃ ನಿರ್ಮಿಸಬೇಕು.</translation>
    </message>
    <message>
        <source>This is the maximum transaction fee you pay (in addition to the normal fee) to prioritize partial spend avoidance over regular coin selection.</source>
        <translation type="unfinished">ನೀವು ಸಾಮಾನ್ಯ ಫೀ ಬಗ್ಗೆ ಹೆಚ್ಚಿನ ಲಾಗಿನ ಸಂದರ್ಶನಕ್ಕಿಂತ ಪಾಂಡ್ರಹಿಸುವುದಕ್ಕಿಂತ ಭಾಗಶಃ ಖರೀದಿ ಟ್ರಾನ್ಸ್ಯಾಕ್ಷನ್ ಆಯ್ಕೆಯನ್ನು ಆಯ್ಕೆಮಾಡುವುದರ ಮೇಲೆ ಪ್ರಾಥಮಿಕತೆಯನ್ನು ಕೊಡುವುದಕ್ಕಾಗಿ ನೀವು ಅಧಿಕವಾದ ಟ್ರಾನ್ಸ್ಯಾಕ್ಷನ್ ಫೀ ಪಾವತಿಸುತ್ತೀರಿ.</translation>
    </message>
    <message>
        <source>Unsupported chainstate database format found. Please restart with -reindex-chainstate. This will rebuild the chainstate database.</source>
        <translation type="unfinished">ಬೆಂಬಲಿಗೆಯ ತರಬೇತಿ ಡೇಟಾಬೇಸ್ ಸ್ವರೂಪ ಅಸಮರ್ಥಿತವಾಗಿದೆ. ದಯವಿಟ್ಟು -reindex-chainstate ನೊಂದಿಗೆ ಮರುಪ್ರಾರಂಭಿಸಿ. ಇದು ಬೆಂಬಲಿಗೆಯ ತರಬೇತಿ ಡೇಟಾಬೇಸ್ ಪೂರ್ತಿಯಾಗಿ ಮರುಸ್ಥಾಪಿಸುತ್ತದೆ.</translation>
    </message>
    <message>
        <source>Error: Duplicate descriptors created during migration. Your wallet may be corrupted.</source>
        <translation type="unfinished">ದೋಷ: ವರ್ಣನೆಗಳ ಪುನರ್ವಿನಿಮಯದ ಸಮಯದಲ್ಲಿ ನಕಲಿ ವರ್ಣನೆಗಳು ರಚಿಸಲಾಗಿವೆ. ನಿಮ್ಮ ಬಟ್ಟೆ ಹಾಕಿದ ಕಾರ್ಟೆಜ್ ಹಾಳಾಗಿರಬಹುದು.</translation>
    </message>
    <message>
        <source>Failed to rename invalid peers.dat file. Please move or delete it and try again.</source>
        <translation type="unfinished">ಅಮಾನ್ಯ ಸಹಾಯಕ ಫೈಲ್ peers.dat ಅನ್ನು ಹೆಸರು ಬದಲಾಯಿಸಲು ವಿಫಲವಾಗಿದೆ. ದಯವಿಟ್ಟು ಅದನ್ನು ತೆಗೆದುಹಾಕಿ ಅಥವಾ ಅದನ್ನು ಹೆಸರು ಬದಲಾಯಿಸಿ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ.</translation>
    </message>
    <message>
        <source>Incompatible options: -dnsseed=1 was explicitly specified, but -onlynet forbids connections to IPv4/IPv6</source>
        <translation type="unfinished">ಅಸಮರ್ಥ ಆಯ್ಕೆಗಳು: -dnsseed=1 ದೃಷ್ಟಿಯಲ್ಲಿದ್ದರೂ, -onlynet ದ್ವಾರಾ IPv4/IPv6 ಸಂಪರ್ಕಗಳನ್ನು ನಿಷೇಧಿಸುತ್ತದೆ.
 
 </translation>
    </message>
    <message>
        <source>Outbound connections restricted to Tor (-onlynet=onion) but the proxy for reaching the Tor network is explicitly forbidden: -onion=0</source>
        <translation type="unfinished">ಹೊರಗಡೆಯ ಸಂಪರ್ಕಗಳು Tor ಗೆ ಮಿತಿಮೀರಿರುವುದು (-onlynet=onion), ಆದರೆ Tor ನೆಟ್ವರ್ಕ್ ತಲುಪಲು ಪ್ರಾಕ್ಸಿ ಸ್ಪಷ್ಟವಾಗಿ ನಿಷೇಧಿಸಲ್ಪಟ್ಟಿದೆ: -onion=0.</translation>
    </message>
    <message>
        <source>Outbound connections restricted to Tor (-onlynet=onion) but the proxy for reaching the Tor network is not provided: none of -proxy, -onion or -listenonion is given</source>
        <translation type="unfinished">ಹೊರಗಡೆಯ ಸಂಪರ್ಕಗಳು Tor ಗೆ ಮಿತಿಮೀರಿರುವುದು (-onlynet=onion), ಆದರೆ Tor ನೆಟ್ವರ್ಕ್ ತಲುಪಲು ಪ್ರಾಕ್ಸಿ ಒದಗಿಸಲ್ಪಡುವುದಿಲ್ಲ: -proxy, -onion ಅಥವಾ -listenonion ಯಲ್ಲಿ ಯಾವುದೇ ಒಂದು ನೀಡಲಾಗಿಲ್ಲ.
 
 </translation>
    </message>
    <message>
        <source>Specified -blockmaxweight (%d) exceeds consensus maximum block weight (%d)</source>
        <translation type="unfinished">ನಿರ್ದಿಷ್ಟ -ಬ್ಲಾಕ್‌ಮ್ಯಾಕ್ಸ್‌ವೈಟ್ (%d) ಸಮ್ಮತಿಯ ಗರಿಷ್ಠ ಬ್ಲಾಕ್ ತೂಕವನ್ನು (%d) ಮೀರಿದೆ</translation>
    </message>
    <message>
        <source>Specified -blockreservedweight (%d) exceeds consensus maximum block weight (%d)</source>
        <translation type="unfinished">ನಿರ್ದಿಷ್ಟ -ಬ್ಲಾಕ್‌ರಿಸರ್ವ್ಡ್‌ವೈಟ್ (%d) ಸಮ್ಮತಿಯ ಗರಿಷ್ಠ ಬ್ಲಾಕ್ ತೂಕವನ್ನು (%d) ಮೀರಿದೆ</translation>
    </message>
    <message>
        <source>Specified -blockreservedweight (%d) is lower than minimum safety value of (%d)</source>
        <translation type="unfinished">ನಿರ್ದಿಷ್ಟ -ಬ್ಲಾಕ್‌ರಿಸರ್ವ್ಡ್‌ವೈಟ್ (%d) ಕನಿಷ್ಠ ಸುರಕ್ಷತಾ ಮೌಲ್ಯಕ್ಕಿಂತ (%d) ಕಡಿಮೆಯಾಗಿದೆ</translation>
    </message>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation type="unfinished">ನೆಲೆಯ ರೆಲೇ ಶುಲ್ಕದಿಂದ ಕಡಿಮೆ ಶುಲ್ಕವನ್ನು ಕೊಡದಂತೆ ವಾಲೆಟ್ ನುಡಿಮುಟ್ಟುವುದು.</translation>
    </message>
    <message>
        <source>This is the minimum transaction fee you pay on every transaction.</source>
        <translation type="unfinished">ನೀವು ಪ್ರತಿಯೊಂದು ಟ್ರಾನ್ಸ್ಯಾಕ್ಷನ್ ಮೇಲೆ ಪಾವತಿ ಶುಲ್ಕವನ್ನು ಕೊಡಬೇಕಾದ ಕನಿಷ್ಠ ಶುಲ್ಕ.</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation type="unfinished">ನೀವು ಟ್ರಾನ್ಸ್ಯಾಕ್ಷನ್ ಕಳುಹಿಸುವಾಗ ನೀವು ಪಾವತಿ ವಿಧಾನದ ಮೂಲಕ ಪಾವತಿ ಶುಲ್ಕವನ್ನು ಪಾವತಿ ಕಳುಹಿಸುವಾಗ ನೀವು ಕೊಡಬೇಕಾದ ಶುಲ್ಕ.</translation>
    </message>
    <message>
        <source>Transaction needs a change address, but we can't generate it.</source>
        <translation type="unfinished">ಲೆಕ್ಕಾಚಾರದಲ್ಲಿ ಬದಲಾವಣೆ ವಿನಂತಿಯನ್ನು ಹೊಂದಿರುವ ಟ್ರಾನ್ಸ್ಯಾಕ್ಷನ್ ಕೆಲವು ಬದಲಾವಣೆ ವಿನಂತಿಗಳನ್ನು ಹೊಂದಿದೆ, ಆದರೆ ಅದನ್ನು ಉಂಟುಮಾಡಲು ಆಗದಿದೆ.</translation>
    </message>
    </context>
</TS>